@@ -1,5 +1,15 @@
 #include <R.h>
 #include <Rinternals.h>
+#ifdef ENABLE_NLS
+#include <libintl.h>
+#define _(String) dgettext ("RxODE", String)
+/* replace pkg as appropriate */
+#else
+#define _(String) (String)
+#endif
+
+void RSprintf(const char *format, ...);
+
 /*
   This is a reentrant-friendly version of the LSODA library.
 
@@ -208,47 +218,47 @@ static int check_opt(struct lsoda_context_t * ctx, struct lsoda_opt_t * opt) {
 	/* default itask is 1 */
 	if (opt->itask == 0) opt->itask = 1;
 	if (opt->itask < 1 || opt->itask > 5) {
-		REprintf("[lsoda] illegal itask = %d\n", opt->itask);
-		return 0;
+	  RSprintf(_("[lsoda] illegal itask = %d\n"), opt->itask);
+	  return 0;
 	}
 
 	if (opt->ixpr < 0 || opt->ixpr > 1) {
-		REprintf("[lsoda] ixpr = %d is illegal\n", opt->ixpr);
-		return 0;
+	  RSprintf(_("[lsoda] ixpr = %d is illegal\n"), opt->ixpr);
+	  return 0;
 	}
 	if (opt->mxstep < 0) {
-		REprintf("[lsoda] mxstep < 0\n");
-		return 0;
+	  RSprintf(_("[lsoda] mxstep < 0\n"));
+	  return 0;
 	}
 	if (opt->mxstep == 0) opt->mxstep = mxstp0;
 	if (opt->mxhnil < 0) {
-		REprintf("[lsoda] mxhnil < 0\n");
-		return 0;
+	  RSprintf(_("[lsoda] mxhnil < 0\n"));
+	  return 0;
 	}
 	if (ctx->state == 1) {
 		if (opt->mxordn < 0) {
-			REprintf("[lsoda] mxordn = %d is less than 0\n", opt->mxordn);
-			return 0;
+		  RSprintf(_("[lsoda] mxordn = %d is less than 0\n"), opt->mxordn);
+		  return 0;
 		}
 		if (opt->mxordn == 0) opt->mxordn = 100;
 		opt->mxordn = min(opt->mxordn, mord[1]);
 		if (opt->mxords < 0) {
-			REprintf("[lsoda] mxords = %d is less than 0\n", opt->mxords);
-			return 0;
+		  RSprintf(_("[lsoda] mxords = %d is less than 0\n"), opt->mxords);
+		  return 0;
 		}
 		if (opt->mxords == 0) opt->mxords = 100;
 		opt->mxords = min(opt->mxords, mord[2]);
 	}	/* end if ( ctx->state == 1 )  */
 	if (opt->hmax < 0.) {
-		REprintf("[lsoda] hmax < 0.\n");
-		return 0;
+	  RSprintf(_("[lsoda] hmax < 0.\n"));
+	  return 0;
 	}
 	opt->hmxi = 0.;
 	if (opt->hmax > 0)
 		opt->hmxi = 1. / opt->hmax;
 	if (opt->hmin < 0.) {
-		REprintf("[lsoda] hmin < 0.\n");
-		return 0;
+	  RSprintf(_("[lsoda] hmin < 0.\n"));
+	  return 0;
 	}
 	return 1;
 }
@@ -477,8 +487,8 @@ void lsoda_reset(struct lsoda_context_t * ctx) {
 void lsoda_free(struct lsoda_context_t * ctx) {
 	free(ctx->common->memory);
 	if(ctx->error) {
-		REprintf("unhandled error message: %s\n", ctx->error);
-		free(ctx->error);
+	  RSprintf(_("unhandled error message: %s\n"), ctx->error);
+	  free(ctx->error);
 	}
 	free(ctx->common);
 }
@@ -755,12 +765,12 @@ int lsoda(struct lsoda_context_t * ctx, double *y, double *t, double tout) {
 			if ((_C(tn) + _C(h)) == _C(tn)) {
 				_C(nhnil)++;
 				if (_C(nhnil) <= opt->mxhnil) {
-					REprintf("lsoda -- warning..internal t = %g and _C(h) = %g are\n", _C(tn), _C(h));
-					REprintf("         such that in the machine, t + _C(h) = t on the next step\n");
-					REprintf("         solver will continue anyway.\n");
+				  RSprintf(_("lsoda -- warning..internal t = %g and _C(h) = %g are\n"), _C(tn), _C(h));
+				  RSprintf(_("         such that in the machine, t + _C(h) = t on the next step\n"));
+				  RSprintf(_("         solver will continue anyway.\n"));
 					if (_C(nhnil) == opt->mxhnil) {
-						REprintf("lsoda -- above warning has been issued %d times,\n", _C(nhnil));
-						REprintf("         it will not be issued again for this problem\n");
+					  RSprintf(_("lsoda -- above warning has been issued %d times,\n"), _C(nhnil));
+					  RSprintf(_("         it will not be issued again for this problem\n"));
 					}
 				}
 			}
@@ -769,10 +779,10 @@ int lsoda(struct lsoda_context_t * ctx, double *y, double *t, double tout) {
 			 */
 			kflag = stoda(ctx, y, jstart);
 			/*
-			   REprintf("_C(meth)= %d,   order= %d,   _C(nfe)= %d,   _C(nje)= %d\n",
+			   RSprintf("_C(meth)= %d,   order= %d,   _C(nfe)= %d,   _C(nje)= %d\n",
 			   _C(meth), _C(nq), _C(nfe), _C(nje) );
-			   REprintf("t= %20.15e,   _C(h)= %20.15e,   _C(nst)=%d\n", _C(tn), _C(h), _C(nst) );
-			   REprintf("y= %20.15e,   %20.15e,   %20.15e\n\n\n",
+			   RSprintf("t= %20.15e,   _C(h)= %20.15e,   _C(nst)=%d\n", _C(tn), _C(h), _C(nst) );
+			   RSprintf("y= %20.15e,   %20.15e,   %20.15e\n\n\n",
 			   _C(yh)[1][1], _C(yh)[1][2], _C(yh)[1][3] );
 			 */
 
@@ -792,10 +802,10 @@ int lsoda(struct lsoda_context_t * ctx, double *y, double *t, double tout) {
 					jstart = -1;
 					if (opt->ixpr) {
 						if (_C(meth) == 2)
-							REprintf("[lsoda] a switch to the stiff method has occurred ");
+						  RSprintf(_("[lsoda] a switch to the stiff method has occurred "));
 						if (_C(meth) == 1)
-							REprintf("[lsoda] a switch to the nonstiff method has occurred");
-						REprintf("at t = %g, tentative step size _C(h) = %g, step _C(nst) = %d\n", _C(tn), _C(h), _C(nst));
+						  RSprintf(_("[lsoda] a switch to the nonstiff method has occurred"));
+						RSprintf(_("at t = %g, tentative step size _C(h) = %g, step _C(nst) = %d\n"), _C(tn), _C(h), _C(nst));
 					}
 				}	/* end if ( _C(meth) != _C(mused) )   */
 				/*
